 Набор правил для склонения русских имён, фамилий и отчеств по падежам.
=======================================================================

Файл содержит 3 группы правил. Это __lastname__, __firstname__ и __middlename__. Каждая группа
содержит подгруппы с правилами:

* Подгруппа __exceptions__ (её может не быть)
* Подгруппа __suffixes__

Правила
-------
В свою очередь, каждая подгруппа содержит набор правил. Каждое правило содержит 3 составляющие:

* Пол (gender). Допустимые значения: __male__, __female__, __androgynous__
* Что заменять - __test__. Массив суффиксов для замены.
* На что заменять - __mods__. Массив модификаторов. Модификатор может иметь впереди один или
	дефис, он означает количество символов, которые нужно будет вырезать из слова.

Правила отделяются друг от друга переносом строки для лучшего восприятия.

Из чего состоят суффиксы
------------------------

 Из чего состоят модификаторы
-----------------------------
родительный, дательный, винительный, творительный, предложный

Как добавить новое правило
--------------------------